summaryrefslogtreecommitdiff
path: root/Libraries/LibWeb/Tests/test-common.js
diff options
context:
space:
mode:
Diffstat (limited to 'Libraries/LibWeb/Tests/test-common.js')
-rw-r--r--Libraries/LibWeb/Tests/test-common.js22
1 files changed, 13 insertions, 9 deletions
diff --git a/Libraries/LibWeb/Tests/test-common.js b/Libraries/LibWeb/Tests/test-common.js
index 7add466d52..54d0b830c6 100644
--- a/Libraries/LibWeb/Tests/test-common.js
+++ b/Libraries/LibWeb/Tests/test-common.js
@@ -1,28 +1,32 @@
// NOTE: The tester loads in LibJS's test-common to prevent duplication.
+// NOTE: "window.libweb_tester" is set to a special tester object.
+// The object currently provides the following functions:
+// - changePage(url) - change page to given URL. Everything afterwards will refer to the new page.
+
let __PageToLoad__;
// This tells the tester which page to load.
// This will only be checked when we look at which page the test wants to use.
// Subsequent calls to loadPage in before/after load will be ignored.
let loadPage;
-let __BeforePageLoad__ = () => {};
+let __BeforeInitialPageLoad__ = () => {};
-// This function will be run just before loading the page.
+// This function will be called just before loading the initial page.
// This is useful for injecting event listeners.
// Defaults to an empty function.
-let beforePageLoad;
+let beforeInitialPageLoad;
-let __AfterPageLoad__ = () => {};
+let __AfterInitialPageLoad__ = () => {};
-// This function will be run just after loading the page.
+// This function will be called just after loading the initial page.
// This is where the main bulk of the tests should be.
// Defaults to an empty function.
-let afterPageLoad;
+let afterInitialPageLoad;
(() => {
loadPage = (page) => __PageToLoad__ = page;
- beforePageLoad = (callback) => __BeforePageLoad__ = callback;
- afterPageLoad = (callback) => __AfterPageLoad__ = callback;
+ beforeInitialPageLoad = (callback) => __BeforeInitialPageLoad__ = callback;
+ afterInitialPageLoad = (callback) => __AfterInitialPageLoad__ = callback;
})();
@@ -1,28 +1,32 @@
// This tells the tester which page to load.
// This will only be checked when we look at which page the test wants to use.
-// Subsequent calls to loadPage in before/after load will be ignored.
+// Subsequent calls to loadPage in before/after initial load will be ignored.
let loadPage;